Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(773)

Unified Diff: content/renderer/input/input_handler_manager.h

Issue 692483002: Hook up DidReceiveInputEvent to the blink scheduler (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Responding to Ross' suggestion Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/input/input_handler_manager.h
diff --git a/content/renderer/input/input_handler_manager.h b/content/renderer/input/input_handler_manager.h
index b6c70700526b9e7a1f907c56a7856f5181316e2d..0c19460df8a0501de4c4c84d422b4e530437f990 100644
--- a/content/renderer/input/input_handler_manager.h
+++ b/content/renderer/input/input_handler_manager.h
@@ -28,16 +28,20 @@ namespace content {
class InputHandlerWrapper;
class InputHandlerManagerClient;
struct DidOverscrollParams;
+class RendererScheduler;
// InputHandlerManager class manages InputHandlerProxy instances for
// the WebViews in this renderer.
class InputHandlerManager {
public:
// |message_loop_proxy| is the MessageLoopProxy of the compositor thread. Both
// the underlying MessageLoop and supplied |client| must outlive this object.
Sami 2014/11/06 22:17:34 nit: s/compositor/fling/ would be a little more ac
alex clarke (OOO till 29th) 2014/11/06 22:32:15 Done.
InputHandlerManager(
const scoped_refptr<base::MessageLoopProxy>& message_loop_proxy,
- InputHandlerManagerClient* client);
+ InputHandlerManagerClient* client,
+ RendererScheduler* renderer_scheduler);
~InputHandlerManager();
// Callable from the main thread only.
@@ -60,6 +64,12 @@ class InputHandlerManager {
// Called from the compositor's thread.
void DidStopFlinging(int routing_id);
+ // Called from the compositor's thread.
+ void DidReceiveInputEvent();
+
+ // Called from the compositor's thread.
+ void DidAnimateForInput();
+
private:
// Called from the compositor's thread.
void AddInputHandlerOnCompositorThread(
@@ -74,6 +84,7 @@ class InputHandlerManager {
scoped_refptr<base::MessageLoopProxy> message_loop_proxy_;
InputHandlerManagerClient* client_;
+ RendererScheduler* renderer_scheduler_; // Not owned.
};
} // namespace content
« no previous file with comments | « no previous file | content/renderer/input/input_handler_manager.cc » ('j') | content/renderer/input/input_handler_wrapper.cc » ('J')
@@ -28,16 +28,20 @@ namespace content {
class InputHandlerManager {
public:
- // |message_loop_proxy| is the MessageLoopProxy of the compositor thread. Both
- // the underlying MessageLoop and supplied |client| must outlive this object.
+ // |message_loop_proxy| is the MessageLoopProxy of the compositor thread. The
+ // underlying MessageLoop and supplied |client| and the |renderer_scheduler|
+ // must outlive this object. The RendererScheduler needs to know when input
+ // events and compositor animations occur, which is why it's passed in here.
Sami 2014/11/06 22:17:34 nit: s/compositor/fling/ would be a little more ac
alex clarke (OOO till 29th) 2014/11/06 22:32:15 Done.

Powered by Google App Engine
This is Rietveld 408576698